package request

type UserAddReq struct {
	UserType       int    `json:"user_type" form:"user_type" binding:"required,oneof=2 3 4"`                        //用户类型
	UserId         string `json:"user_id" form:"user_id" binding:"required"`                                        //账号
	UserName       string `json:"user_name" form:"user_name" binding:"required"`                                    //负责人
	Email          string `json:"email" form:"email" binding:"email"`                                               //邮箱
	Password       string `json:"password" form:"password" binding:"required,gte=6"`                                //密码
	PassWordRepeat string `json:"password_repeat" form:"password_repeat" binding:"required,gte=6,eqfield=password"` //重复密码

	//普通用户、租户 独有字段
	UnitName string `json:"unit_name" form:"unit_name" binding:"omitempty"` //单位名称
	Phone    string `json:"phone" form:"phone" binding:"omitempty"`         //联系方式
	Id       string `json:"id" form:"id" binding:"omitempty"`               //用户唯一标识
}

type UserListReq struct {
	Keyword  string `json:"keyword" form:"keyword" binding:"omitempty"`                   //搜索关键词
	UserType int    `json:"user_type" form:"user_type" binding:"omitempty,oneof=1 2 3 4"` //用户类型
	UserId   string `json:"user_id" form:"user_id" binding:"omitempty"`                   //账号
	Id       string `json:"id" form:"id" binding:"omitempty"`                             //用户唯一标识
	OrderBy  string `json:"order_by" form:"order_by" binding:"omitempty"`                 //排序
	Pagination
}

type UserDelReq struct {
	UserIds []string `json:"user_ids" form:"user_ids[]" binding:"required"` //用户账号集合
}

type UserUpdateReq struct {
	OptType string `json:"opt_type" form:"opt_type" binding:"required,oneof=change_pass reset_pass change_info"`
	UserId  string `json:"user_id" form:"user_id" binding:"required"` //账号

	//基础信息
	UserName string `json:"user_name" form:"user_name" binding:"omitempty,required_if=opt_type change_info"` //负责人
	Email    string `json:"email" form:"email" binding:"omitempty,required_if=opt_type change_info,email"`   //邮箱

	//迁移人员 独有字段
	UnitName string `json:"unit_name" form:"unit_name" binding:"omitempty,required_if=opt_type change_info"` //迁移单位名称
	Phone    string `json:"phone" form:"phone" binding:"omitempty,required_if=opt_type change_info"`         //联系方式

	//修改密码、重置密码
	OriginalPassword string `json:"original_password" form:"original_password" binding:"required_if=opt_type change_pass,omitempty,gte=6"`                                              //原始密码
	Password         string `json:"password" form:"password" binding:"required_if=opt_type change_pass,required_if=opt_type reset_pass,omitempty,gte=6"`                                //新密码
	PassWordRepeat   string `json:"password_repeat" form:"password_repeat" binding:"required_if=opt_type change_pass,required_if=opt_type reset_pass,omitempty,gte=6,eqfield=password"` //重复密码
}
